<template>
  <a-card :bordered="false" :class="'cust-erp-sub-tab'">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator" v-if="mainId">
      <!-- <a-button @click="handleAdd" type="primary" icon="plus" :disabled="!this.mainId">新增</a-button> -->
      <a-button type="primary" icon="download" @click="handleExportXls('仓库服务对象')" v-if="false">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl"
        @change="handleImportExcel">
        <a-button type="primary" icon="import" v-if="false">导入</a-button>
      </a-upload>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete" />删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown>
    </div>
    <!--  权限控制   v-if="hasBtnPerm('verificationExcution:save')"-->
    <a-button type="primary" @click="handleAdd" style="margin-bottom: 20px;">上传</a-button>
    <a-table ref="table" size="middle" bordered rowKey="id" :scroll="{ x: true }" :columns="columns"
      :dataSource="dataSource" :pagination="ipagination" :loading="loading" @change="handleTableChange">
      <template slot="htmlSlot" slot-scope="text">
        <div v-html="text"></div>
      </template>
      <template slot="imgSlot" slot-scope="text,record">
        <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
        <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt=""
          style="max-width:80px;font-size: 12px;font-style: italic;" />
      </template>
      <template slot="fileSlot" slot-scope="text">
        <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
        <a-button v-else :ghost="true" type="primary" icon="download" size="small" @click="downloadFile(text)">
          下载
        </a-button>
      </template>

      <span slot="action" slot-scope="text, record">
        <a @click="handleEdit(record)">编辑</a>
        <a-divider type="vertical" />
        <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
          <a>删除</a>
        </a-popconfirm>
      </span>
    </a-table>
    <!-- <warehouseClient-modal ref="modalForm" @ok="modalFormOk" :mainId="mainId" :enterpriseId="enterpriseId"
      :originTargetKeys="originTargetKeys"></warehouseClient-modal> -->
    <upload-model ref="modalForm" @ok="modalFormOk1"></upload-model>
  </a-card>
</template>
<style>
.notShow {
  display: none
}
</style>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import WarehouseClientModal from './modules/WarehouseClientModal'
import { getAction, postAction } from '@/api/manage'
import UploadModel from './modules/uploadModel.vue'
export default {
  name: "WarehouseClientList",
  mixins: [JeecgListMixin],
  components: { WarehouseClientModal, UploadModel },
  props: {
    mainId: {
      type: String,
      default: '',
      required: false
    },
    enterpriseId: {
      type: String,
      default: '',
      required: false
    }
  },
  watch: {
    mainId: {
      immediate: true,
      handler(val) {
        if (!this.mainId) {
          this.clearList()
        } else {
          this.queryParam['calibrationOrderId'] = val;
          this.queryParam['delFlag'] = '0';
          this.isButtonShow = true;
          this.loadData(1);
          this.selectedRowKeys = [];
        }
      }
    }
  },
  data() {
    return {
      description: '检定附件报告',
      disableMixinCreated: true,
      // 表头
      columns: [
        {
          title: '文档编号',
          align: "center",
          dataIndex: 'upload',
          customRender: function (t, r, index) {
            return r.upload.id
          }
        },
        {
          title: '文档名称',
          align: "center",
          dataIndex: 'name',
          customRender: function (t, r, index) {
            return r.upload.name
          }
        },

        {
          title: '文档类型',
          align: "center",
          dataIndex: '',
          width: 220,
          customRender: function (t, r, index) {
            return r.upload.format
          }
        },
        {
          title: '上传时间',
          align: "center",
          width: 220,
          customRender: function (t, r, index) {
            return r.upload.createTime
          }

        },
        {
          title: '上传者',
          align: "center",
          customRender: function (t, r, index) {
            return r.upload.createBy
          }
        },
        {
          title: '大小',
          align: "center",
          customRender: function (t, r, index) {
            return r.upload.size
          }
        },

        // {
        //   title: '操作',
        //   dataIndex: 'action',
        //   align: "center",
        //   fixed: "right",
        //   width: 200,
        //   scopedSlots: { customRender: 'action' },
        // }
      ],
      url: {
        list: "/sys/uploadRela/listByBusIdAndBusType",
        upload: '/eam/calibrationOrder/addAttachmentRelation',
        delete: "/eam/calibrationOrderDetail/delete",
        deleteBatch: "/eam/calibrationOrderDetail/deleteBatch",
        exportXlsUrl: "/eam/calibrationOrderDetail/exportWarehouseClient",
        importUrl: "/eam/calibrationOrderDetail/importWarehouseClient",
      },
      dictOptions: {
      },
      originTargetKeys: []
    }
  },
  created() {

  },
  computed: {
    importExcelUrl() {
      return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`;
    }
  },
  methods: {
    handleAdd() {
      this.$refs.modalForm.add();
      this.$refs.modalForm.title = "文件上传";
      this.$refs.modalForm.disableSubmit = false;
    },
    modalFormOk1(e) {
      e.result.forEach(res => {
        res.businessAssociationId = this.mainId
        res.description = this.$refs.modalForm.checked
      })
      setTimeout(() => {
        postAction('/eam/calibrationOrder/addAttachmentRelation', e.result).then(res => {
          this.loadData(1);
        })
      }, 200)
    },

    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      params.busType = 'calibration_order_photo'
      params.busId = this.mainId
      this.loading = true;
      this.originTargetKeys = [];
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records || res.result;
          for (var i = 0; i < res.result.records.length; i++) {
            var clientId = res.result.records[i]['clientId']
            this.originTargetKeys.push(clientId)
          }
          if (res.result.total) {
            this.ipagination.total = res.result.total;
          } else {
            this.ipagination.total = 0;
          }
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less'
</style>
